@@ -12,7 +12,7 @@ from .misc import (connect_nums, connect_strs, copy_files, copy_the_file,
                    decapitalize, fmt_size, grep, is_defined_global,
                    is_defined_local, is_later_or_equal, isclose, listed_dict,
                    merge_dicts_wo_overlaps, pop_keys, search, squeeze_spaces,
-                   take_the_closest)
+                   take_the_closest, is_nan)
 from .pandas import col_to_last, col_to_top, force_dataframe, merge_columns
 from .repro import *
 from .TimeStamper import *
